Description Usage Arguments Value Author(s)
Function to calculate AUC values for response curves using Trapezoidal integration.
1 | AUC(x, y, baseline = 0)
|
x |
the x coordinates of points in the curve |
y |
the y coordinates of points in the curve |
baseline |
baseline value of y axis |
Returns a data.frame containing all AUC's calculated
Robert Ernst
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.